@@ -25,6 +25,7 @@
 
 #define MOZILLA_CLIENT
 
+#include <mozilla-config.h>
 #include <gtkmozembed.h>
 #include <nsXPCOM.h>
 #include <nsIGenericFactory.h>
@@ -50,6 +51,9 @@
 #include <gtkmozembed_glue.cpp>
 #include <nsGenericFactory.h>
 #endif
+#ifdef HAVE_GECKO_1_9
+#  include <nsComponentManagerUtils.h>
+#endif
 
 NS_GENERIC_FACTORY_CONSTRUCTOR(KzFilePicker)
 NS_GENERIC_FACTORY_CONSTRUCTOR(KzContentHandler)
